@@ -40,14 +40,8 @@ Spreadsheet::Engine::Function::VAR - Spreadsheet funtion VAR()
 
 =head1 DESCRIPTION
 
-This provides the spreadsheet text funtion VAR()
-
-=head2 calculate
-
 This returns the variance.
 
-=head2 result
-
 We calculate as per Knuth "The Art of Computer Programming" Vol. 2
 3rd edition, page 232
 
