@@ -9,37 +9,7 @@ use Encode;
 use Spreadsheet::Engine::Sheet
   qw/function_args_error operand_as_number operand_as_text operand_value_and_type/;
 
-sub argument_count { 1 }
-
-sub _opvals {
-  my $self = shift;
-
-  my $numargs = scalar @{ $self->foperand };
-  my @argdef  = @{ $self->arguments };
-
-  my @opvals = ();
-
-  for my $sig (@argdef[ 0 .. $numargs - 1 ]) {
-    my $op;
-
-    if ($sig =~ /^([<>]=?)(\d+)/) {    # >=0 <1 etc.
-      my ($test, $num) = ($1, $2);
-      $op = $self->next_operand_as_number;
-      my $val = $op->value;
-      die Spreadsheet::Engine::Error->val('Invalid arguments')
-        unless eval "$val $test $num";
-    } elsif ($sig == 0) {              # any number
-      $op = $self->next_operand_as_number;
-    } elsif ($sig == 1) {              # any string
-      $op = $self->next_operand_as_text;
-      $op->value(decode('utf8', $op->value));
-    }
-
-    die $op if $op->is_error;
-    push @opvals, $op->value;
-  }
-  return @opvals;
-}
+sub signature { 't' }
 
 sub result {
   my $self = shift;
@@ -64,8 +34,6 @@ Spreadsheet::Engine::Function::text - base class for text functions
 
   use base 'Spreadsheet::Engine::Function::text';
 
-  sub arguments { [ 1 ] }
-
   sub calculate { ... }
 
 =head1 DESCRIPTION
@@ -73,10 +41,6 @@ Spreadsheet::Engine::Function::text - base class for text functions
 This provides a base class for spreadsheet functions that operate on
 text, such as UPPER(), LOWER(), REPLACE() etc.
 
-Subclasses should provide an 'arguments' method detailing the number and
-type of arguments they should receive, and a 'calculate' function that
-will be called with those arguments.
-
 =head1 INSTANCE METHODS
 
 =head2 calculate
